@@ -14,11 +14,11 @@ __title__ = 'github3'
 __author__ = 'Ian Cordasco'
 __license__ = 'Modified BSD'
 __copyright__ = 'Copyright 2012-2014 Ian Cordasco'
-__version__ = '0.9.0'
+__version__ = '0.9.2'
 __version_info__ = tuple(int(i) for i in __version__.split('.'))
 
-from github3.api import *
-from github3.github import GitHub, GitHubEnterprise, GitHubStatus
-from github3.models import GitHubError
+from .api import *
+from .github import GitHub, GitHubEnterprise, GitHubStatus
+from .models import GitHubError
 
 # flake8: noqa
